<?php

require('includes/custom-widget.php');

//Add a style sheet and scripts to the wp_header
if(!is_admin()){
	
	wp_enqueue_style('tfs_enhanced', get_template_directory_uri() . '/css/enhanced.css');
	wp_enqueue_script('tfs_modernizr', get_template_directory_uri() . '/js/modernizr.js', array('jquery')  );
	
}


//Add a customer Header
$args = array(
	'flex-width'    => true,
	'width'         => 980,
	'flex-height'    => true,
	'height'        => 200,
	'default-image' => get_template_directory_uri() . '/images/header.jpg',
);
add_theme_support( 'custom-header', $args );


//Add custom background
$defaults = array(
	'default-color'          => '',
	'default-image'          => '',
	'wp-head-callback'       => '_custom_background_cb',
	'admin-head-callback'    => '',
	'admin-preview-callback' => ''
);
add_theme_support( 'custom-background', $defaults );

//Add custom menu support
function register_my_menus() {
  register_nav_menus(
    array(
      'header-menu' => __( 'Header Menu' ),
      'footer-menu' => __( 'Footer Menu' ),
	  'service-menu' => __( 'Service Menu')
    )
  );
}
add_action( 'init', 'register_my_menus' );

//Add featured image support
add_theme_support( 'post-thumbnails' );

//Add main sidebar and secondary sidebar for use in widget area
register_sidebar(array(
  'name' => __( 'Sidebar' ),
  'id' => 'sidebar',
  'description' => __( 'Widgets in this area will be shown on the main sidebar beneath the content.' ),
  'before_title' => '<h1>',
  'after_title' => '</h1>'
));

register_sidebar(array(
  'name' => __( 'Smooth Scroll Area' ),
  'id' => 'smooth-scroll',
  'description' => __( 'Widgets in this area will be shown on Pages using the Custom Page template - Smooth Scroll Template - available to Pages.' ),
  'before_title' => '<h1>',
  'after_title' => '</h1>'
));


// Adds the Customize page to the WordPress admin area if you did not add 'add_theme_support'
// above. Causes duplicate Customize menu if you do
//  
// function example_customizer_menu() {
//     add_theme_page( 'Customizer', 'Customizer', 'edit_theme_options', 'customize.php' );
// }
// add_action( 'admin_menu', 'example_customizer_menu' );


// Adds the individual sections, settings, and controls to the theme customizer
function example_customizer( $wp_customize ) {
	$wp_customize->add_section(
	    'themeFromScratch_section_one',
	    array(
	        'title' => 'Theme Settings',
	        'description' => 'This is a settings section.',
	        'priority' => 35,
	    )
	);


	//Custom Logo
		$wp_customize->add_section( 'themeslug_logo_section' , array(
		    'title'       => __( 'Logo', 'themeslug' ),
		    'priority'    => 30,
		    'description' => 'Upload a logo to replace the default site name and description in the header',
		) );

		$wp_customize->add_setting( 'themeslug_logo' );

		$wp_customize->add_control( 
			new WP_Customize_Image_Control( 
				$wp_customize, 'themeslug_logo', array(
			    'label'    => __( 'Logo', 'themeslug' ),
			    'section'  => 'themeslug_logo_section',
			    'settings' => 'themeslug_logo'
				) 
			) 
		);


	//Copyright information
	$wp_customize->add_setting(
	 'copyright_textbox',
	 array(
	     'default' => 'Default copyright text',
	 )
	);

	$wp_customize->add_control(
	 'copyright_textbox',
	 array(
	     'label' => 'Copyright text',
	     'section' => 'themeFromScratch_section_one',
	     'type' => 'text',
	 )
	);
	$wp_customize->add_setting(
	    'hide_copyright'
	);
	
	$wp_customize->add_control(
	    'hide_copyright',
	    array(
	        'type' => 'checkbox',
	        'label' => 'Hide copyright text',
	        'section' => 'themeFromScratch_section_one',
	    )
	);
	
	$wp_customize->add_setting(
	    'page-setting',
	    array(
	        'sanitize_callback' => 'themeFromScratch_sanitize_integer',
	    )
	);

	$wp_customize->add_control(
	    'page-setting',
	    array(
	        'type' => 'dropdown-pages',
	        'label' => 'Choose a page:',
	        'section' => 'themeFromScratch_section_one',
	    )
	);
	
}
add_action( 'customize_register', 'example_customizer' );


function themeFromScratch_sanitize_integer( $input ) {
    if( is_numeric( $input ) ) {
        return intval( $input );
    }
}



//Twentythirteen nav and paging functions renamed to themeFromScratch_ ...
if ( ! function_exists( 'themeFromScratch_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since Twenty Thirteen 1.0
 *
 * @return void
 */
function themeFromScratch_paging_nav() {
	global $wp_query;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'themeFromScratch' ); ?></h1>
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'themeFromScratch' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'themeFromScratch' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'themeFromScratch_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
*
* @since Twenty Thirteen 1.0
*
* @return void
*/
function themeFromScratch_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<nav class="navigation post-navigation" role="navigation">
		<h1 class="screen-reader-text"><?php _e( 'Post navigation', 'themeFromScratch' ); ?></h1>
		<div class="nav-links">

			<?php previous_post_link( '%link', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'themeFromScratch' ) ); ?>
			<?php next_post_link( '%link', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'themeFromScratch' ) ); ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;


?>