<?php

//Make a widget for our Smooth Scroll sidebar

// Creating the widget 
class themeFromScratch_widget extends WP_Widget {

	function __construct() {
		parent::__construct(
		// Base ID of your widget
		'themeFromScratch_widget', 

		// Widget name will appear in UI
		__('Smooth Scroll Widget', 'themeFromScratch_widget_domain'), 

		// Widget description
		array( 'description' => __( 'Use this widget to display the latest posts or pages by dragging it onto the Smooth Scroll sidebar and specifying the pages and posts you want to show.', 'themeFromScratch_widget_domain' ), ) 
		);
	}

	// Creating widget front-end
	// This is where the action happens
	public function widget( $args, $instance ) {
		
		//get default arguments defined by theme
		extract($args);
		
		//make new variables for our widget arguments
		$count = $instance['count'];
		$page_ids = $instance['pages'];
		$show_excerpt = isset( $instance['excerpt'] ) ? $instance['excerpt'] : false;
		$show_posts = isset( $instance['latest_posts'] ) ? $instance['latest_posts'] : false;
		
		// before and after widget arguments are defined by themes
		echo $before_widget;
		global $post;
		
		?>
		<?php if($show_posts) : ?>
			<ul>
			<?php
			$options = array( 'posts_per_page' => $count );
		
			$myposts = get_posts( $options );
			foreach ( $myposts as $post ) : setup_postdata( $post ); ?>
				<li>
					<?php
					if($show_excerpt) {
					 	the_excerpt(); 
					} else {
						get_template_part( 'content');
					}
					?>
				</li>
			<?php endforeach; 
			wp_reset_postdata();?>
		
			</ul>
		<?php endif; ?>
		
		<?php if($page_ids) : ?>
			<ul>
			<?php
			$options = array( 'include' => $page_ids );
		
			$myposts = get_pages( $options );
			foreach ( $myposts as $post ) : setup_postdata( $post ); ?>
				<li>
					<?php
					if($show_excerpt) {
					 	the_excerpt(); 
					} else {
						get_template_part( 'content');
					}
					?>
				</li>
			<?php endforeach; 
			wp_reset_postdata();?>
		
			</ul>
		<?php endif; ?>
		
		<?php	

		echo $after_widget;
	}
		
	// Widget Backend 
	public function form( $instance ) {
		
		/* Set up some default widget settings. */
		$defaults = array( 'count' => '5', 'excerpt' => true, 'latest_posts' => true, 'page_ids' => '');
		$instance = wp_parse_args( (array) $instance, $defaults );
		
		// Widget admin form
			?>
			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['latest_posts'], true) ?> id="<?php echo $this->get_field_id('latest_posts'); ?>" name="<?php echo $this->get_field_name('latest_posts'); ?>" />
				<label for="<?php echo $this->get_field_id('latest_posts'); ?>"><?php _e('Show Latest Posts'); ?></label>
			</p>
			
			
			<p>
				<label for="<?php echo $this->get_field_id( 'count' ); ?>">Post Count:</label>
				<input id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>" style="width:1em" />
			</p>

			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['excerpt'], true) ?> id="<?php echo $this->get_field_id('excerpt'); ?>" name="<?php echo $this->get_field_name('excerpt'); ?>" />
				<label for="<?php echo $this->get_field_id('excerpt'); ?>"><?php _e('Show Excerpt Only'); ?></label>
			</p>
			
			<p>
				<label for="<?php echo $this->get_field_id( 'pages' ); ?>">Comma separated list of page or post id numbers to show:</label>
				<input id="<?php echo $this->get_field_id( 'pages' ); ?>" name="<?php echo $this->get_field_name( 'pages' ); ?>" value="<?php echo $instance['pages']; ?>" style="width:100%" />
			</p>
			
	<?php 
	}
	
	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		
		//array of boolean values and checkboxes
		$instance = array( 'excerpt' => 0, 'latest_posts' => 0);
		foreach ( $instance as $field => $val ) {
			if ( isset($new_instance[$field]) )
				$instance[$field] = 1;
		}
		
		$instance['count'] = ( !empty( $new_instance['count'] ) ) ? strip_tags( $new_instance['count'] ) : '';
		$instance['pages'] = ( !empty( $new_instance['pages'] ) ) ? strip_tags( $new_instance['pages'] ) : '';

		return $instance;
	}
} // Class themeFromScratch_widget ends here

// Register and load the widget
function themeFromScratch_load_widget() {
	register_widget( 'themeFromScratch_widget' );
}
add_action( 'widgets_init', 'themeFromScratch_load_widget' );

?>